## intent:greet
- Salut !
- Bonjour !
- Salut !

## intent:farewell
- Bonne chance.
- À la revoyure.
- au revoir.

## intent:affirm
- Je comprends.
- J'essaye.
- Lève-toi.
- Va, maintenant.
- Allez-y maintenant.
- Vas-y maintenant.
- J'ai pigé !
- Compris !
- Je l'utilise.
- J'en fais usage.
- Je m'en sers.
- Je paierai.
- Je vais essayer.
- J'essaierai.

## intent:deny
- C'est pas possible !
- Impossible !
- En aucun cas.
- Sans façons !
- C'est hors de question !
- Il n'en est pas question !
- C'est exclu !
- En aucune manière !
- Hors de question !

## intent:stop
- Ça suffit !
- Stop !
- Arrête-toi !

## intent:thank
- Comme c'est chouette !
- Comme c'est gentil !
- C'est du joli !
- Comme c'est agréable !
